@@ -23,6 +23,7 @@ from typing import (
     Dict,
     List,
     Optional,
+    Protocol,
     TypeVar,
     Union,
     cast,
@@ -52,7 +53,7 @@ Sync = Literal[False]
 A = TypeVar("A", Async, Sync, covariant=True)
 
 # Global references to prevent garbage collection for `add_event_loop_shutdown_callback`
-EVENT_LOOP_GC_REFS = {}
+EVENT_LOOP_GC_REFS: dict[Any, Any] = {}
 
 GLOBAL_THREAD_LIMITER: Optional[anyio.CapacityLimiter] = None
 
@@ -161,8 +162,6 @@ async def _async_generator_timeout(async_gen, timeout):
         )
 
 
-T = TypeVar("T")
-
 global_stop = threading.Event()
 
 
@@ -227,23 +226,19 @@ def async_iterator(
     return inner
 
 
-class FunctionWithStop(Callable):
-    global_stop: asyncio.Event
+class FunctionWithStop(Protocol):
+    global_stop: threading.Event
 
-    def __call__(self) -> None: ...
+    def __call__(self, *args: Any, **kwargs: Any) -> Any: ...
 
 
-if TYPE_CHECKING:
-    async_iterator: FunctionWithStop
+if not TYPE_CHECKING:
+    setattr(async_iterator, "global_stop", global_stop)
 
-setattr(async_iterator, "global_stop", global_stop)
-
-
-T = TypeVar("T")
 
 
 async def handle_signals(scope: anyio.abc.CancelScope):
-    async with anyio.open_signal_receiver(signal.SIGINT, signal.SIGTERM) as signals:
+    async with anyio.open_signal_receiver(signal.SIGINT, signal.SIGTERM) as signals:  # type: ignore[attr-defined]
         async for signum in signals:
             logger.info(f"Received signal: {signum}")
             scope.cancel()  # This cancels th
@@ -271,7 +266,7 @@ async def _run_with(
 async def map_as_completed(
     fn: Callable[..., Awaitable[T]],
     *inputs: dict[str, Any],
-    name: str = None,
+    name: str | None = None,
     progress: bool = True,
     return_exceptions: bool = True,
     exclude_exceptions: bool = False,
@@ -401,7 +396,7 @@ async def map_as_completed(
 async def map_as_completed_dict(
     fn: Callable[..., Awaitable[T]],
     inputs: dict[Any, dict[str, Any]],
-    name: str = None,
+    name: str | None = None,
     progress: bool = True,
     return_exceptions: bool = True,
     exclude_exceptions: bool = False,
@@ -512,8 +507,6 @@ async def run_with_semaphore(
         return await coro
 
 
-T = TypeVar("T")
-
 
 def retry_async(
     retries: int = 3,
