@@ -16,6 +16,26 @@ from pydantic import BaseModel
 from pydantic.main import IncEx
 from ._functional import filter_nulls, try_chain
 
+# Version detection for jsonpath_rust_bindings
+import importlib.metadata
+import re as _re
+
+def _get_jsonpath_version():
+    """Get the version of jsonpath_rust_bindings as a tuple."""
+    try:
+        version_str = importlib.metadata.version('jsonpath_rust_bindings')
+        # Parse version string like "1.0.0" or "0.7.0"
+        match = _re.match(r'^(\d+)\.(\d+)\.(\d+)', version_str)
+        if match:
+            return tuple(int(x) for x in match.groups())
+    except Exception:
+        pass
+    # Default to assuming old version if we can't detect
+    return (0, 7, 0)
+
+_JSONPATH_VERSION = _get_jsonpath_version()
+_IS_JSONPATH_V1_PLUS = _JSONPATH_VERSION[0] >= 1
+
 # Type aliases
 DictLike = typing.Union[dict, "DotDict"]
 D = typing.TypeVar("D", bound=dict | MutableMapping)
@@ -889,11 +909,136 @@ class DotDict(MutableMapping):
 
 
 def find(json: dict, query: str):
+    """
+    Execute a JSONPath query on a JSON-like dictionary.
+    
+    Args:
+        json: The JSON data to query
+        query: JSONPath query string
+        
+    Returns:
+        List of JsonPathResult objects
+    """
     return Finder(json).find(query)
 
 
 def find_non_empty(json: dict, query: str):
-    return Finder(json).find_non_empty(query)
+    """
+    Execute a JSONPath query and filter out empty/null results.
+    
+    Automatically handles both pre-1.0 and 1.0+ versions of jsonpath-rust-bindings.
+    
+    Args:
+        json: The JSON data to query
+        query: JSONPath query string
+        
+    Returns:
+        List of JsonPathResult objects with non-empty data
+    """
+    if _IS_JSONPATH_V1_PLUS:
+        # Version 1.0+: find_non_empty() was removed, filter manually
+        results = Finder(json).find(query)
+        
+        # Filter out None, empty strings, empty lists, empty dicts
+        # Keeping 0 and False as they are valid non-empty values
+        def is_non_empty(data):
+            if data is None:
+                return False
+            if isinstance(data, (str, list, dict)) and len(data) == 0:
+                return False
+            return True
+        
+        return [r for r in results if is_non_empty(r.data)]
+    else:
+        # Pre-1.0: Use the built-in find_non_empty method
+        return Finder(json).find_non_empty(query)  # type: ignore[attr-defined]
+
+
+def find_with_regex(json: dict, query: str, regex_replacements: dict | None = None):
+    """
+    Execute a JSONPath query with regex pattern matching support.
+    
+    Handles both pre-1.0 (with native regex support) and 1.0+ versions.
+    
+    Args:
+        json: The JSON data to query
+        query: JSONPath query string (regex patterns will be extracted)
+        regex_replacements: Optional dict mapping field names to regex patterns
+        
+    Returns:
+        List of JsonPathResult objects matching the patterns
+        
+    Example:
+        # Pre-1.0: $.books[?(@.author ~= '.*Melville')]
+        # 1.0+: find_with_regex(data, '$.books[*]', {'author': '.*Melville'})
+    """
+    if _IS_JSONPATH_V1_PLUS:
+        # Version 1.0+: regex operator ~= is no longer supported, use post-filtering
+        import re
+        
+        # Remove regex filters from query to get base query
+        base_query = re.sub(r'\[\?\([^)]*~=[^)]*\)\]', '[*]', query)
+        
+        # Extract regex patterns from original query if not provided
+        if regex_replacements is None:
+            regex_replacements = {}
+            # Pattern to extract field and regex from filter expressions
+            pattern = r'\[\?\(@\.(\w+)\s*~=\s*[\'"]([^\'"]*)[\'"]\)\]'
+            matches = re.findall(pattern, query)
+            for field, regex_pattern in matches:
+                regex_replacements[field] = regex_pattern
+        
+        # Get all results from base query
+        results = Finder(json).find(base_query)
+        
+        # Filter results based on regex patterns
+        if regex_replacements:
+            filtered_results = []
+            for result in results:
+                data = result.data
+                if isinstance(data, dict):
+                    # Check if all regex patterns match
+                    all_match = True
+                    for field, pattern in regex_replacements.items():
+                        if field in data:
+                            value = str(data[field]) if data[field] is not None else ''
+                            if not re.search(pattern, value):
+                                all_match = False
+                                break
+                        else:
+                            all_match = False
+                            break
+                    if all_match:
+                        filtered_results.append(result)
+                else:
+                    filtered_results.append(result)
+            return filtered_results
+        
+        return results
+    else:
+        # Pre-1.0: Use native regex support in JSONPath queries
+        return Finder(json).find(query)
+
+
+def find_or_empty(json: dict, query: str):
+    """
+    Execute a JSONPath query with consistent behavior across versions.
+    
+    In pre-1.0 versions, non-existent paths returned a single result with empty data.
+    This function provides consistent behavior across versions.
+    
+    Args:
+        json: The JSON data to query
+        query: JSONPath query string
+        
+    Returns:
+        List of JsonPathResult objects
+    """
+    results = Finder(json).find(query)
+    
+    # Both versions should return the same - just the results as-is
+    # The behavioral difference was in the library itself, not our usage
+    return results
 
 
 # Helper functions for DotDict
