@@ -54,7 +54,7 @@ def simple_pipeline(
 def simple_pipeline(*functions: Callable) -> Callable: ...
 
 
-def simple_pipeline(*functions: Callable) -> Callable:
+def simple_pipeline(*functions: Callable) -> Callable:  # type: ignore[misc]
     """Create a simple_pipeline function from a sequence of callables.
 
     The returned function's input type matches the first function's input type,
@@ -306,7 +306,7 @@ def _flatten_and_filter(result: typing.Any, return_paths: bool) -> typing.List:
     return [result] if result is not None else []
 
 
-def anyget(obj: typing.Any, key: str, default: X = None) -> T | X:
+def anyget(obj: typing.Any, key: str, default: X | None = None) -> T | X | None:
     if isinstance(obj, Mapping):
         return obj.get(key, default)
     elif hasattr(obj, key):
@@ -341,18 +341,15 @@ def set_defaults(__base: dict | None = None, **kwargs):
     return __base
 
 
-T = typing.TypeVar("T")
-
-
 def filter_nulls(obj: T) -> T:
     if isinstance(obj, dict):
-        return {
+        return {  # type: ignore[return-value]
             k: v
             for k, v in ((k, filter_nulls(v)) for k, v in obj.items())
             if v not in (None, {}, [])
         }
     elif isinstance(obj, list):
-        return [v for v in (filter_nulls(v) for v in obj) if v not in (None, {}, [])]
+        return [v for v in (filter_nulls(v) for v in obj) if v not in (None, {}, [])]  # type: ignore[return-value]
     else:
         return obj
 
